@@ -209,8 +209,8 @@ class mothe:
 
         bb_train = bb_model.fit(train_X, train_label, batch_size=batch_size,epochs=epochs,verbose=1,validation_data=(valid_X, valid_label))
 
-        accuracy =bb_train.history['acc']
-        val_accuracy = bb_train.history['val_acc']
+        accuracy =bb_train.history['accuracy']
+        val_accuracy = bb_train.history['val_accuracy']
         loss = bb_train.history['loss']
         val_loss = bb_train.history['val_loss']
         epochs = range(len(accuracy))
@@ -343,9 +343,10 @@ class mothe:
 
           for item in pts:
             data = data.append(pd.DataFrame({'frame': i, 'x': item[0], 'y': item[1],}, index=[0]), ignore_index=True)
+            data.to_csv(path + "/detect.csv")
             cv2.rectangle(frame,(item[0]-grabsize, item[1]-grabsize), (item[0]+grabsize, item[1]+grabsize),(0,255,0),thickness = 2)
           out.write(frame)
-        data.to_csv(path + "detect.csv")
+
         cap.release()
         out.release()
 
